@@ -72,7 +72,7 @@ use Carp;
 use CGI;
 
 our @ISA = qw(CGI);
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # Package globals
 
@@ -210,6 +210,7 @@ sub _canCompress
 
    my $compress = 1;
    my $reason = "";
+   my @newheader = (@$header);
 
    # Check programmer preference
    $compress &&= $global_use_compression;
@@ -262,12 +263,12 @@ sub _canCompress
       {
          if (defined $encodingIndex)
          {
-            $header->[$encodingIndex] =~ s/^(?:-?Content[-_]Encoding:\s*)/gzip, /mio
-                or $header->[$encodingIndex] = "gzip, " . $header->[$encodingIndex];
+            $newheader[$encodingIndex] =~ s/^(?:-?Content[-_]Encoding:\s*)/gzip, /mio
+                or $newheader[$encodingIndex] = "gzip, " . $newheader[$encodingIndex];
          }
          else
          {
-            push @$header, "-Content_Encoding", "gzip";
+            push @newheader, "-Content_Encoding", "gzip";
          }
       }
    }
@@ -293,8 +294,14 @@ sub _canCompress
    }
    $reason ||= "IO::Zlib not found" if (!$compress);
 
-   push @$header, "-X_non_gzip_reason", $reason 
-       if ((!$compress) && $global_give_reason);
+   if ($compress)
+   {
+      @$header = @newheader;
+   }
+   else
+   {
+      push @$header, "-X_non_gzip_reason", $reason if ($global_give_reason);
+   }
 
    return $compress;
 }
@@ -352,7 +359,7 @@ package CGI::Compress::Gzip::wrapper;
 CGI::Compress::Gzip also implements a helper class in package
 CGI::Compress::Gzip::wrapper which subclasses IO::Zlib.  This helper
 is needed to make sure that output is not compressed until the CGI
-header is emitted.  This wrappers delays the ignition of the zlib
+header is emitted.  This wrapper delays the ignition of the zlib
 filter until it sees the exact same header generated by
 CGI::Compress::Gzip::header() pass through it's WRITE() method.  If
 you change the header before printing it, this class will throw an
@@ -497,9 +504,9 @@ __END__
 
 =head1 TO DO
 
-* Fix under Windows (MinGW)  Help please!
+* Fix under Windows (MinGW) -- Help please!
 
-* test in FastCGI environments
+* test in FastCGI environments -- Help please!
 
 * Handle errors more gracefully in WRITE()
 
